# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'FastPlot.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_FastPlot(object):
    def setupUi(self, FastPlot):
        FastPlot.setObjectName("FastPlot")
        FastPlot.resize(750, 579)
        FastPlot.setIconSize(QtCore.QSize(24, 24))
        self.centralwidget = QtGui.QWidget(FastPlot)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayoutWidget = QtGui.QWidget(self.centralwidget)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(0, 0, 751, 531))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.topLayout = QtGui.QVBoxLayout(self.verticalLayoutWidget)
        self.topLayout.setContentsMargins(0, 0, 0, 0)
        self.topLayout.setObjectName("topLayout")
        self.ButtonFrame = QtGui.QFrame(self.verticalLayoutWidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ButtonFrame.sizePolicy().hasHeightForWidth())
        self.ButtonFrame.setSizePolicy(sizePolicy)
        self.ButtonFrame.setMinimumSize(QtCore.QSize(0, 40))
        self.ButtonFrame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.ButtonFrame.setFrameShadow(QtGui.QFrame.Raised)
        self.ButtonFrame.setObjectName("ButtonFrame")
        self.btPrev = QtGui.QPushButton(self.ButtonFrame)
        self.btPrev.setGeometry(QtCore.QRect(30, 10, 121, 27))
        self.btPrev.setObjectName("btPrev")
        self.btNxt = QtGui.QPushButton(self.ButtonFrame)
        self.btNxt.setGeometry(QtCore.QRect(170, 10, 98, 27))
        self.btNxt.setObjectName("btNxt")
        self.strNum = QtGui.QLabel(self.ButtonFrame)
        self.strNum.setEnabled(True)
        self.strNum.setGeometry(QtCore.QRect(300, 10, 180, 20))
        self.strNum.setObjectName("strNum")
        self.strXY = QtGui.QLabel(self.ButtonFrame)
        self.strXY.setEnabled(True)
        self.strXY.setGeometry(QtCore.QRect(480, 10, 251, 21))
        self.strXY.setObjectName("strXY")
        self.topLayout.addWidget(self.ButtonFrame)
        FastPlot.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(FastPlot)
        self.menubar.setEnabled(True)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 750, 25))
        self.menubar.setObjectName("menubar")
        FastPlot.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(FastPlot)
        self.statusbar.setObjectName("statusbar")
        FastPlot.setStatusBar(self.statusbar)

        self.retranslateUi(FastPlot)
        QtCore.QMetaObject.connectSlotsByName(FastPlot)

    def retranslateUi(self, FastPlot):
        FastPlot.setWindowTitle(QtGui.QApplication.translate("FastPlot", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.btPrev.setText(QtGui.QApplication.translate("FastPlot", "<< Previous", None, QtGui.QApplication.UnicodeUTF8))
        self.btNxt.setText(QtGui.QApplication.translate("FastPlot", "Next >>", None, QtGui.QApplication.UnicodeUTF8))
        self.strNum.setText(QtGui.QApplication.translate("FastPlot", "Page: 0/0 (0/0)", None, QtGui.QApplication.UnicodeUTF8))
        self.strXY.setText(QtGui.QApplication.translate("FastPlot", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgPlotPtn.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgPlotPtn(object):
    def setupUi(self, DgPlotPtn):
        DgPlotPtn.setObjectName("DgPlotPtn")
        DgPlotPtn.resize(423, 389)
        self.ckAutoApply = QtGui.QCheckBox(DgPlotPtn)
        self.ckAutoApply.setGeometry(QtCore.QRect(170, 10, 111, 22))
        self.ckAutoApply.setObjectName("ckAutoApply")
        self.btSaveDefAtt = QtGui.QPushButton(DgPlotPtn)
        self.btSaveDefAtt.setGeometry(QtCore.QRect(300, 10, 111, 27))
        self.btSaveDefAtt.setObjectName("btSaveDefAtt")
        self.Linepanel = QtGui.QFrame(DgPlotPtn)
        self.Linepanel.setGeometry(QtCore.QRect(0, 40, 421, 91))
        self.Linepanel.setFrameShape(QtGui.QFrame.WinPanel)
        self.Linepanel.setFrameShadow(QtGui.QFrame.Raised)
        self.Linepanel.setObjectName("Linepanel")
        self.label = QtGui.QLabel(self.Linepanel)
        self.label.setGeometry(QtCore.QRect(10, 10, 81, 21))
        self.label.setObjectName("label")
        self.cbLineStyle = QtGui.QComboBox(self.Linepanel)
        self.cbLineStyle.setGeometry(QtCore.QRect(110, 10, 111, 27))
        self.cbLineStyle.setObjectName("cbLineStyle")
        self.cbLineStyle.addItem("")
        self.cbLineStyle.addItem("")
        self.cbLineStyle.addItem("")
        self.cbLineStyle.addItem("")
        self.cbLineStyle.addItem("")
        self.ckHist = QtGui.QCheckBox(self.Linepanel)
        self.ckHist.setGeometry(QtCore.QRect(250, 10, 131, 22))
        self.ckHist.setObjectName("ckHist")
        self.label_2 = QtGui.QLabel(self.Linepanel)
        self.label_2.setGeometry(QtCore.QRect(10, 50, 81, 17))
        self.label_2.setObjectName("label_2")
        self.spLineWidth = QtGui.QSpinBox(self.Linepanel)
        self.spLineWidth.setGeometry(QtCore.QRect(110, 50, 60, 21))
        self.spLineWidth.setObjectName("spLineWidth")
        self.label_3 = QtGui.QLabel(self.Linepanel)
        self.label_3.setGeometry(QtCore.QRect(210, 50, 51, 17))
        self.label_3.setObjectName("label_3")
        self.cbLineColor = QtGui.QComboBox(self.Linepanel)
        self.cbLineColor.setGeometry(QtCore.QRect(260, 50, 131, 27))
        self.cbLineColor.setObjectName("cbLineColor")
        self.cbLineColor.addItem("")
        self.cbLineColor.addItem("")
        self.cbLineColor.addItem("")
        self.cbLineColor.addItem("")
        self.cbLineColor.addItem("")
        self.cbLineColor.addItem("")
        self.cbLineColor.addItem("")
        self.cbLineColor.addItem("")
        self.Linepanel_2 = QtGui.QFrame(DgPlotPtn)
        self.Linepanel_2.setGeometry(QtCore.QRect(0, 140, 421, 91))
        self.Linepanel_2.setFrameShape(QtGui.QFrame.WinPanel)
        self.Linepanel_2.setFrameShadow(QtGui.QFrame.Raised)
        self.Linepanel_2.setObjectName("Linepanel_2")
        self.label_4 = QtGui.QLabel(self.Linepanel_2)
        self.label_4.setGeometry(QtCore.QRect(10, 10, 81, 21))
        self.label_4.setObjectName("label_4")
        self.cbSymbolType = QtGui.QComboBox(self.Linepanel_2)
        self.cbSymbolType.setGeometry(QtCore.QRect(110, 10, 111, 27))
        self.cbSymbolType.setObjectName("cbSymbolType")
        self.cbSymbolType.addItem("")
        self.cbSymbolType.addItem("")
        self.cbSymbolType.addItem("")
        self.cbSymbolType.addItem("")
        self.cbSymbolType.addItem("")
        self.cbSymbolType.addItem("")
        self.cbSymbolType.addItem("")
        self.cbSymbolType.addItem("")
        self.ckFilledFace = QtGui.QCheckBox(self.Linepanel_2)
        self.ckFilledFace.setGeometry(QtCore.QRect(250, 10, 131, 22))
        self.ckFilledFace.setObjectName("ckFilledFace")
        self.label_5 = QtGui.QLabel(self.Linepanel_2)
        self.label_5.setGeometry(QtCore.QRect(10, 50, 81, 17))
        self.label_5.setObjectName("label_5")
        self.spSymbolSize = QtGui.QSpinBox(self.Linepanel_2)
        self.spSymbolSize.setGeometry(QtCore.QRect(110, 50, 60, 21))
        self.spSymbolSize.setObjectName("spSymbolSize")
        self.label_6 = QtGui.QLabel(self.Linepanel_2)
        self.label_6.setGeometry(QtCore.QRect(210, 50, 51, 17))
        self.label_6.setObjectName("label_6")
        self.cbSymbolColor = QtGui.QComboBox(self.Linepanel_2)
        self.cbSymbolColor.setGeometry(QtCore.QRect(260, 50, 131, 27))
        self.cbSymbolColor.setObjectName("cbSymbolColor")
        self.cbSymbolColor.addItem("")
        self.cbSymbolColor.addItem("")
        self.cbSymbolColor.addItem("")
        self.cbSymbolColor.addItem("")
        self.cbSymbolColor.addItem("")
        self.cbSymbolColor.addItem("")
        self.cbSymbolColor.addItem("")
        self.cbSymbolColor.addItem("")
        self.Linepanel_3 = QtGui.QFrame(DgPlotPtn)
        self.Linepanel_3.setGeometry(QtCore.QRect(0, 240, 421, 91))
        self.Linepanel_3.setFrameShape(QtGui.QFrame.WinPanel)
        self.Linepanel_3.setFrameShadow(QtGui.QFrame.Raised)
        self.Linepanel_3.setObjectName("Linepanel_3")
        self.ckErrorBar = QtGui.QCheckBox(self.Linepanel_3)
        self.ckErrorBar.setGeometry(QtCore.QRect(10, 10, 131, 22))
        self.ckErrorBar.setObjectName("ckErrorBar")
        self.label_8 = QtGui.QLabel(self.Linepanel_3)
        self.label_8.setGeometry(QtCore.QRect(10, 50, 81, 17))
        self.label_8.setObjectName("label_8")
        self.spCapSize = QtGui.QSpinBox(self.Linepanel_3)
        self.spCapSize.setGeometry(QtCore.QRect(110, 50, 60, 21))
        self.spCapSize.setObjectName("spCapSize")
        self.label_9 = QtGui.QLabel(self.Linepanel_3)
        self.label_9.setGeometry(QtCore.QRect(210, 50, 51, 17))
        self.label_9.setObjectName("label_9")
        self.cbErrorColor = QtGui.QComboBox(self.Linepanel_3)
        self.cbErrorColor.setGeometry(QtCore.QRect(260, 50, 131, 27))
        self.cbErrorColor.setObjectName("cbErrorColor")
        self.cbErrorColor.addItem("")
        self.cbErrorColor.addItem("")
        self.cbErrorColor.addItem("")
        self.cbErrorColor.addItem("")
        self.cbErrorColor.addItem("")
        self.cbErrorColor.addItem("")
        self.cbErrorColor.addItem("")
        self.cbErrorColor.addItem("")
        self.btClose = QtGui.QPushButton(DgPlotPtn)
        self.btClose.setGeometry(QtCore.QRect(40, 350, 81, 27))
        self.btClose.setObjectName("btClose")
        self.btApplyThis = QtGui.QPushButton(DgPlotPtn)
        self.btApplyThis.setGeometry(QtCore.QRect(220, 350, 81, 27))
        self.btApplyThis.setObjectName("btApplyThis")
        self.btApply = QtGui.QPushButton(DgPlotPtn)
        self.btApply.setGeometry(QtCore.QRect(320, 350, 81, 27))
        self.btApply.setObjectName("btApply")

        self.retranslateUi(DgPlotPtn)
        QtCore.QMetaObject.connectSlotsByName(DgPlotPtn)

    def retranslateUi(self, DgPlotPtn):
        DgPlotPtn.setWindowTitle(QtGui.QApplication.translate("DgPlotPtn", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.ckAutoApply.setText(QtGui.QApplication.translate("DgPlotPtn", "Auto Apply", None, QtGui.QApplication.UnicodeUTF8))
        self.btSaveDefAtt.setText(QtGui.QApplication.translate("DgPlotPtn", "Save as default", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgPlotPtn", "Line Style: ", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineStyle.setItemText(0, QtGui.QApplication.translate("DgPlotPtn", "Line", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineStyle.setItemText(1, QtGui.QApplication.translate("DgPlotPtn", "Dotted", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineStyle.setItemText(2, QtGui.QApplication.translate("DgPlotPtn", "Dashed", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineStyle.setItemText(3, QtGui.QApplication.translate("DgPlotPtn", "Dot-dashed", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineStyle.setItemText(4, QtGui.QApplication.translate("DgPlotPtn", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.ckHist.setText(QtGui.QApplication.translate("DgPlotPtn", "Histogram", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DgPlotPtn", "Line Width: ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DgPlotPtn", "Color:", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineColor.setItemText(0, QtGui.QApplication.translate("DgPlotPtn", "Auto", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineColor.setItemText(1, QtGui.QApplication.translate("DgPlotPtn", "Blue", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineColor.setItemText(2, QtGui.QApplication.translate("DgPlotPtn", "Green", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineColor.setItemText(3, QtGui.QApplication.translate("DgPlotPtn", "Red", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineColor.setItemText(4, QtGui.QApplication.translate("DgPlotPtn", "Cyan", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineColor.setItemText(5, QtGui.QApplication.translate("DgPlotPtn", "Magenta", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineColor.setItemText(6, QtGui.QApplication.translate("DgPlotPtn", "Yellow", None, QtGui.QApplication.UnicodeUTF8))
        self.cbLineColor.setItemText(7, QtGui.QApplication.translate("DgPlotPtn", "Black", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DgPlotPtn", "Symbol:", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolType.setItemText(0, QtGui.QApplication.translate("DgPlotPtn", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolType.setItemText(1, QtGui.QApplication.translate("DgPlotPtn", "Dot", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolType.setItemText(2, QtGui.QApplication.translate("DgPlotPtn", "Circle", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolType.setItemText(3, QtGui.QApplication.translate("DgPlotPtn", "Square", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolType.setItemText(4, QtGui.QApplication.translate("DgPlotPtn", "Triangle", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolType.setItemText(5, QtGui.QApplication.translate("DgPlotPtn", "Diamond", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolType.setItemText(6, QtGui.QApplication.translate("DgPlotPtn", "Cross", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolType.setItemText(7, QtGui.QApplication.translate("DgPlotPtn", "Crisscross", None, QtGui.QApplication.UnicodeUTF8))
        self.ckFilledFace.setText(QtGui.QApplication.translate("DgPlotPtn", "Filled face", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DgPlotPtn", "Symbol Size:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("DgPlotPtn", "Color:", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolColor.setItemText(0, QtGui.QApplication.translate("DgPlotPtn", "Auto", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolColor.setItemText(1, QtGui.QApplication.translate("DgPlotPtn", "Blue", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolColor.setItemText(2, QtGui.QApplication.translate("DgPlotPtn", "Green", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolColor.setItemText(3, QtGui.QApplication.translate("DgPlotPtn", "Red", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolColor.setItemText(4, QtGui.QApplication.translate("DgPlotPtn", "Cyan", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolColor.setItemText(5, QtGui.QApplication.translate("DgPlotPtn", "Magenta", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolColor.setItemText(6, QtGui.QApplication.translate("DgPlotPtn", "Yellow", None, QtGui.QApplication.UnicodeUTF8))
        self.cbSymbolColor.setItemText(7, QtGui.QApplication.translate("DgPlotPtn", "Black", None, QtGui.QApplication.UnicodeUTF8))
        self.ckErrorBar.setText(QtGui.QApplication.translate("DgPlotPtn", "With Error Bar", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("DgPlotPtn", "Cap Size:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("DgPlotPtn", "Color:", None, QtGui.QApplication.UnicodeUTF8))
        self.cbErrorColor.setItemText(0, QtGui.QApplication.translate("DgPlotPtn", "Auto", None, QtGui.QApplication.UnicodeUTF8))
        self.cbErrorColor.setItemText(1, QtGui.QApplication.translate("DgPlotPtn", "Blue", None, QtGui.QApplication.UnicodeUTF8))
        self.cbErrorColor.setItemText(2, QtGui.QApplication.translate("DgPlotPtn", "Green", None, QtGui.QApplication.UnicodeUTF8))
        self.cbErrorColor.setItemText(3, QtGui.QApplication.translate("DgPlotPtn", "Red", None, QtGui.QApplication.UnicodeUTF8))
        self.cbErrorColor.setItemText(4, QtGui.QApplication.translate("DgPlotPtn", "Cyan", None, QtGui.QApplication.UnicodeUTF8))
        self.cbErrorColor.setItemText(5, QtGui.QApplication.translate("DgPlotPtn", "Magenta", None, QtGui.QApplication.UnicodeUTF8))
        self.cbErrorColor.setItemText(6, QtGui.QApplication.translate("DgPlotPtn", "Yellow", None, QtGui.QApplication.UnicodeUTF8))
        self.cbErrorColor.setItemText(7, QtGui.QApplication.translate("DgPlotPtn", "Black", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DgPlotPtn", "Close", None, QtGui.QApplication.UnicodeUTF8))
        self.btApplyThis.setText(QtGui.QApplication.translate("DgPlotPtn", "Apply", None, QtGui.QApplication.UnicodeUTF8))
        self.btApply.setText(QtGui.QApplication.translate("DgPlotPtn", "Apply All", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgScaleLabel.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgScaleLabel(object):
    def setupUi(self, DgScaleLabel):
        DgScaleLabel.setObjectName("DgScaleLabel")
        DgScaleLabel.resize(462, 204)
        self.frame = QtGui.QFrame(DgScaleLabel)
        self.frame.setGeometry(QtCore.QRect(0, 0, 461, 161))
        self.frame.setFrameShape(QtGui.QFrame.WinPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.layoutWidget = QtGui.QWidget(self.frame)
        self.layoutWidget.setGeometry(QtCore.QRect(20, 50, 211, 29))
        self.layoutWidget.setObjectName("layoutWidget")
        self.horizontalLayout_3 = QtGui.QHBoxLayout(self.layoutWidget)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_3 = QtGui.QLabel(self.layoutWidget)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        self.ylabel = QtGui.QLineEdit(self.layoutWidget)
        self.ylabel.setObjectName("ylabel")
        self.horizontalLayout_3.addWidget(self.ylabel)
        self.layoutWidget_2 = QtGui.QWidget(self.frame)
        self.layoutWidget_2.setGeometry(QtCore.QRect(260, 50, 191, 29))
        self.layoutWidget_2.setObjectName("layoutWidget_2")
        self.horizontalLayout_4 = QtGui.QHBoxLayout(self.layoutWidget_2)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_4 = QtGui.QLabel(self.layoutWidget_2)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_4.addWidget(self.label_4)
        self.yunit = QtGui.QLineEdit(self.layoutWidget_2)
        self.yunit.setObjectName("yunit")
        self.horizontalLayout_4.addWidget(self.yunit)
        self.label_5 = QtGui.QLabel(self.frame)
        self.label_5.setGeometry(QtCore.QRect(20, 100, 71, 17))
        self.label_5.setObjectName("label_5")
        self.spFS = QtGui.QSpinBox(self.frame)
        self.spFS.setGeometry(QtCore.QRect(80, 120, 60, 27))
        self.spFS.setObjectName("spFS")
        self.label_6 = QtGui.QLabel(self.frame)
        self.label_6.setGeometry(QtCore.QRect(180, 100, 91, 17))
        self.label_6.setObjectName("label_6")
        self.layoutWidget1 = QtGui.QWidget(self.frame)
        self.layoutWidget1.setGeometry(QtCore.QRect(260, 10, 191, 29))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.horizontalLayout = QtGui.QHBoxLayout(self.layoutWidget1)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_2 = QtGui.QLabel(self.layoutWidget1)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.xunit = QtGui.QLineEdit(self.layoutWidget1)
        self.xunit.setObjectName("xunit")
        self.horizontalLayout.addWidget(self.xunit)
        self.layoutWidget2 = QtGui.QWidget(self.frame)
        self.layoutWidget2.setGeometry(QtCore.QRect(20, 11, 211, 29))
        self.layoutWidget2.setObjectName("layoutWidget2")
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.layoutWidget2)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtGui.QLabel(self.layoutWidget2)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        self.xlabel = QtGui.QLineEdit(self.layoutWidget2)
        self.xlabel.setObjectName("xlabel")
        self.horizontalLayout_2.addWidget(self.xlabel)
        self.cbFont = QtGui.QComboBox(self.frame)
        self.cbFont.setGeometry(QtCore.QRect(240, 120, 201, 27))
        self.cbFont.setObjectName("cbFont")
        self.btCancel = QtGui.QPushButton(DgScaleLabel)
        self.btCancel.setGeometry(QtCore.QRect(270, 170, 98, 27))
        self.btCancel.setObjectName("btCancel")
        self.btOK = QtGui.QPushButton(DgScaleLabel)
        self.btOK.setGeometry(QtCore.QRect(90, 170, 98, 27))
        self.btOK.setObjectName("btOK")

        self.retranslateUi(DgScaleLabel)
        QtCore.QMetaObject.connectSlotsByName(DgScaleLabel)

    def retranslateUi(self, DgScaleLabel):
        DgScaleLabel.setWindowTitle(QtGui.QApplication.translate("DgScaleLabel", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DgScaleLabel", "Y Label:", None, QtGui.QApplication.UnicodeUTF8))
        self.ylabel.setText(QtGui.QApplication.translate("DgScaleLabel", "Counts", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DgScaleLabel", "Y Unit:", None, QtGui.QApplication.UnicodeUTF8))
        self.yunit.setText(QtGui.QApplication.translate("DgScaleLabel", "Counts", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DgScaleLabel", "Font Size:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("DgScaleLabel", "Font Type:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DgScaleLabel", "X Unit:", None, QtGui.QApplication.UnicodeUTF8))
        self.xunit.setText(QtGui.QApplication.translate("DgScaleLabel", "micro sec", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgScaleLabel", "X Label:", None, QtGui.QApplication.UnicodeUTF8))
        self.xlabel.setText(QtGui.QApplication.translate("DgScaleLabel", "Time", None, QtGui.QApplication.UnicodeUTF8))
        self.btCancel.setText(QtGui.QApplication.translate("DgScaleLabel", "Cancel", None, QtGui.QApplication.UnicodeUTF8))
        self.btOK.setText(QtGui.QApplication.translate("DgScaleLabel", "OK", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgSetting.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgSetting(object):
    def setupUi(self, DgSetting):
        DgSetting.setObjectName("DgSetting")
        DgSetting.setWindowModality(QtCore.Qt.NonModal)
        DgSetting.resize(394, 486)
        DgSetting.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        DgSetting.setModal(False)
        self.scpanel = QtGui.QFrame(DgSetting)
        self.scpanel.setGeometry(QtCore.QRect(0, 0, 391, 271))
        self.scpanel.setFrameShape(QtGui.QFrame.WinPanel)
        self.scpanel.setFrameShadow(QtGui.QFrame.Raised)
        self.scpanel.setLineWidth(1)
        self.scpanel.setObjectName("scpanel")
        self.scpanel_2 = QtGui.QFrame(self.scpanel)
        self.scpanel_2.setGeometry(QtCore.QRect(10, 10, 371, 121))
        self.scpanel_2.setFrameShape(QtGui.QFrame.WinPanel)
        self.scpanel_2.setFrameShadow(QtGui.QFrame.Raised)
        self.scpanel_2.setLineWidth(1)
        self.scpanel_2.setObjectName("scpanel_2")
        self.label = QtGui.QLabel(self.scpanel_2)
        self.label.setGeometry(QtCore.QRect(10, 10, 66, 17))
        self.label.setObjectName("label")
        self.ckXAuto = QtGui.QCheckBox(self.scpanel_2)
        self.ckXAuto.setGeometry(QtCore.QRect(10, 30, 97, 22))
        self.ckXAuto.setChecked(True)
        self.ckXAuto.setObjectName("ckXAuto")
        self.ckLogX = QtGui.QCheckBox(self.scpanel_2)
        self.ckLogX.setGeometry(QtCore.QRect(10, 90, 97, 22))
        self.ckLogX.setObjectName("ckLogX")
        self.label_2 = QtGui.QLabel(self.scpanel_2)
        self.label_2.setGeometry(QtCore.QRect(30, 60, 66, 17))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtGui.QLabel(self.scpanel_2)
        self.label_3.setGeometry(QtCore.QRect(210, 60, 16, 17))
        self.label_3.setObjectName("label_3")
        self.x0 = QtGui.QLineEdit(self.scpanel_2)
        self.x0.setGeometry(QtCore.QRect(100, 60, 101, 21))
        self.x0.setObjectName("x0")
        self.x1 = QtGui.QLineEdit(self.scpanel_2)
        self.x1.setGeometry(QtCore.QRect(230, 60, 101, 21))
        self.x1.setObjectName("x1")
        self.btXApply = QtGui.QPushButton(self.scpanel_2)
        self.btXApply.setGeometry(QtCore.QRect(290, 90, 71, 27))
        self.btXApply.setObjectName("btXApply")
        self.scpanel_3 = QtGui.QFrame(self.scpanel)
        self.scpanel_3.setGeometry(QtCore.QRect(10, 140, 371, 121))
        self.scpanel_3.setFrameShape(QtGui.QFrame.WinPanel)
        self.scpanel_3.setFrameShadow(QtGui.QFrame.Raised)
        self.scpanel_3.setLineWidth(1)
        self.scpanel_3.setObjectName("scpanel_3")
        self.label_4 = QtGui.QLabel(self.scpanel_3)
        self.label_4.setGeometry(QtCore.QRect(10, 10, 66, 17))
        self.label_4.setObjectName("label_4")
        self.ckYAuto = QtGui.QCheckBox(self.scpanel_3)
        self.ckYAuto.setGeometry(QtCore.QRect(10, 30, 97, 22))
        self.ckYAuto.setChecked(True)
        self.ckYAuto.setObjectName("ckYAuto")
        self.ckLogY = QtGui.QCheckBox(self.scpanel_3)
        self.ckLogY.setGeometry(QtCore.QRect(10, 90, 97, 22))
        self.ckLogY.setObjectName("ckLogY")
        self.label_5 = QtGui.QLabel(self.scpanel_3)
        self.label_5.setGeometry(QtCore.QRect(30, 60, 66, 17))
        self.label_5.setObjectName("label_5")
        self.label_6 = QtGui.QLabel(self.scpanel_3)
        self.label_6.setGeometry(QtCore.QRect(210, 60, 16, 17))
        self.label_6.setObjectName("label_6")
        self.y0 = QtGui.QLineEdit(self.scpanel_3)
        self.y0.setGeometry(QtCore.QRect(100, 60, 101, 21))
        self.y0.setObjectName("y0")
        self.y1 = QtGui.QLineEdit(self.scpanel_3)
        self.y1.setGeometry(QtCore.QRect(230, 60, 101, 21))
        self.y1.setObjectName("y1")
        self.btYApply = QtGui.QPushButton(self.scpanel_3)
        self.btYApply.setGeometry(QtCore.QRect(290, 90, 71, 27))
        self.btYApply.setObjectName("btYApply")
        self.stpanel = QtGui.QFrame(DgSetting)
        self.stpanel.setGeometry(QtCore.QRect(0, 280, 391, 101))
        self.stpanel.setFrameShape(QtGui.QFrame.WinPanel)
        self.stpanel.setFrameShadow(QtGui.QFrame.Raised)
        self.stpanel.setLineWidth(1)
        self.stpanel.setObjectName("stpanel")
        self.ckOver = QtGui.QCheckBox(self.stpanel)
        self.ckOver.setGeometry(QtCore.QRect(10, 10, 97, 22))
        self.ckOver.setObjectName("ckOver")
        self.label_7 = QtGui.QLabel(self.stpanel)
        self.label_7.setGeometry(QtCore.QRect(30, 40, 66, 17))
        self.label_7.setObjectName("label_7")
        self.spX = QtGui.QSpinBox(self.stpanel)
        self.spX.setGeometry(QtCore.QRect(110, 40, 60, 21))
        self.spX.setObjectName("spX")
        self.spY = QtGui.QSpinBox(self.stpanel)
        self.spY.setGeometry(QtCore.QRect(270, 40, 60, 21))
        self.spY.setObjectName("spY")
        self.label_8 = QtGui.QLabel(self.stpanel)
        self.label_8.setGeometry(QtCore.QRect(200, 40, 66, 17))
        self.label_8.setObjectName("label_8")
        self.label_9 = QtGui.QLabel(self.stpanel)
        self.label_9.setGeometry(QtCore.QRect(20, 70, 91, 17))
        self.label_9.setObjectName("label_9")
        self.spN = QtGui.QSpinBox(self.stpanel)
        self.spN.setGeometry(QtCore.QRect(110, 70, 60, 21))
        self.spN.setObjectName("spN")
        self.fspanel = QtGui.QFrame(DgSetting)
        self.fspanel.setGeometry(QtCore.QRect(0, 390, 391, 51))
        self.fspanel.setFrameShape(QtGui.QFrame.WinPanel)
        self.fspanel.setFrameShadow(QtGui.QFrame.Raised)
        self.fspanel.setLineWidth(1)
        self.fspanel.setObjectName("fspanel")
        self.label_10 = QtGui.QLabel(self.fspanel)
        self.label_10.setGeometry(QtCore.QRect(10, 10, 71, 20))
        self.label_10.setObjectName("label_10")
        self.spFS = QtGui.QSpinBox(self.fspanel)
        self.spFS.setGeometry(QtCore.QRect(80, 10, 60, 21))
        self.spFS.setObjectName("spFS")
        self.label_11 = QtGui.QLabel(self.fspanel)
        self.label_11.setGeometry(QtCore.QRect(150, 10, 81, 17))
        self.label_11.setObjectName("label_11")
        self.label_12 = QtGui.QLabel(self.fspanel)
        self.label_12.setGeometry(QtCore.QRect(20, 90, 91, 17))
        self.label_12.setObjectName("label_12")
        self.spN_2 = QtGui.QSpinBox(self.fspanel)
        self.spN_2.setGeometry(QtCore.QRect(110, 90, 60, 21))
        self.spN_2.setObjectName("spN_2")
        self.cbFontBox = QtGui.QComboBox(self.fspanel)
        self.cbFontBox.setGeometry(QtCore.QRect(230, 10, 151, 27))
        self.cbFontBox.setObjectName("cbFontBox")
        self.btClose = QtGui.QPushButton(DgSetting)
        self.btClose.setGeometry(QtCore.QRect(150, 450, 98, 27))
        self.btClose.setObjectName("btClose")

        self.retranslateUi(DgSetting)
        QtCore.QMetaObject.connectSlotsByName(DgSetting)

    def retranslateUi(self, DgSetting):
        DgSetting.setWindowTitle(QtGui.QApplication.translate("DgSetting", "Set Parameter", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgSetting", "X axis", None, QtGui.QApplication.UnicodeUTF8))
        self.ckXAuto.setText(QtGui.QApplication.translate("DgSetting", "Auto Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.ckLogX.setText(QtGui.QApplication.translate("DgSetting", "Log Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DgSetting", "X Range :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DgSetting", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.btXApply.setText(QtGui.QApplication.translate("DgSetting", "Apply", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DgSetting", "Y axis", None, QtGui.QApplication.UnicodeUTF8))
        self.ckYAuto.setText(QtGui.QApplication.translate("DgSetting", "Auto Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.ckLogY.setText(QtGui.QApplication.translate("DgSetting", "Log Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DgSetting", "Y Range :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("DgSetting", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.btYApply.setText(QtGui.QApplication.translate("DgSetting", "Apply", None, QtGui.QApplication.UnicodeUTF8))
        self.ckOver.setText(QtGui.QApplication.translate("DgSetting", "Overlay", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("DgSetting", "X offset :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("DgSetting", "Y offset :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("DgSetting", "Max Traces :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("DgSetting", "Font size :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("DgSetting", "Font Type :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("DgSetting", "Max Traces :", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DgSetting", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgTitle.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgTitle(object):
    def setupUi(self, DgTitle):
        DgTitle.setObjectName("DgTitle")
        DgTitle.resize(470, 259)
        self.frame = QtGui.QFrame(DgTitle)
        self.frame.setGeometry(QtCore.QRect(0, 0, 471, 221))
        self.frame.setFrameShape(QtGui.QFrame.WinPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.label = QtGui.QLabel(self.frame)
        self.label.setGeometry(QtCore.QRect(20, 10, 71, 17))
        self.label.setObjectName("label")
        self.tx1 = QtGui.QLineEdit(self.frame)
        self.tx1.setGeometry(QtCore.QRect(10, 30, 451, 27))
        self.tx1.setObjectName("tx1")
        self.label_2 = QtGui.QLabel(self.frame)
        self.label_2.setGeometry(QtCore.QRect(20, 70, 81, 17))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtGui.QLabel(self.frame)
        self.label_3.setGeometry(QtCore.QRect(20, 170, 71, 17))
        self.label_3.setObjectName("label_3")
        self.spFS = QtGui.QSpinBox(self.frame)
        self.spFS.setGeometry(QtCore.QRect(80, 190, 60, 27))
        self.spFS.setObjectName("spFS")
        self.label_4 = QtGui.QLabel(self.frame)
        self.label_4.setGeometry(QtCore.QRect(180, 170, 91, 17))
        self.label_4.setObjectName("label_4")
        self.tx2 = QtGui.QPlainTextEdit(self.frame)
        self.tx2.setGeometry(QtCore.QRect(20, 90, 431, 61))
        self.tx2.setObjectName("tx2")
        self.cbFont = QtGui.QComboBox(self.frame)
        self.cbFont.setGeometry(QtCore.QRect(240, 190, 211, 27))
        self.cbFont.setObjectName("cbFont")
        self.btOK = QtGui.QPushButton(DgTitle)
        self.btOK.setGeometry(QtCore.QRect(90, 230, 98, 27))
        self.btOK.setObjectName("btOK")
        self.btCancel = QtGui.QPushButton(DgTitle)
        self.btCancel.setGeometry(QtCore.QRect(270, 230, 98, 27))
        self.btCancel.setObjectName("btCancel")

        self.retranslateUi(DgTitle)
        QtCore.QMetaObject.connectSlotsByName(DgTitle)

    def retranslateUi(self, DgTitle):
        DgTitle.setWindowTitle(QtGui.QApplication.translate("DgTitle", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgTitle", "Main Title", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DgTitle", "Sub Title", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DgTitle", "Font Size:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DgTitle", "Font Type:", None, QtGui.QApplication.UnicodeUTF8))
        self.btOK.setText(QtGui.QApplication.translate("DgTitle", "OK", None, QtGui.QApplication.UnicodeUTF8))
        self.btCancel.setText(QtGui.QApplication.translate("DgTitle", "Cancel", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'FloatBox.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_FloatBox(object):
    def setupUi(self, FloatBox):
        FloatBox.setObjectName("FloatBox")
        FloatBox.resize(474, 362)
        self.centralwidget = QtGui.QWidget(FloatBox)
        self.centralwidget.setObjectName("centralwidget")
        self.frame = QtGui.QFrame(self.centralwidget)
        self.frame.setGeometry(QtCore.QRect(10, 10, 451, 281))
        self.frame.setFrameShape(QtGui.QFrame.WinPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.label = QtGui.QLabel(self.frame)
        self.label.setGeometry(QtCore.QRect(20, 10, 111, 17))
        self.label.setObjectName("label")
        self.spNo = QtGui.QSpinBox(self.frame)
        self.spNo.setGeometry(QtCore.QRect(10, 240, 60, 27))
        self.spNo.setObjectName("spNo")
        self.btPlot = QtGui.QPushButton(self.frame)
        self.btPlot.setGeometry(QtCore.QRect(330, 50, 101, 27))
        self.btPlot.setObjectName("btPlot")
        self.btChange = QtGui.QPushButton(self.frame)
        self.btChange.setGeometry(QtCore.QRect(330, 240, 111, 27))
        self.btChange.setObjectName("btChange")
        self.txEdit = QtGui.QLineEdit(self.frame)
        self.txEdit.setGeometry(QtCore.QRect(80, 240, 241, 27))
        self.txEdit.setObjectName("txEdit")
        self.specList = QtGui.QListWidget(self.frame)
        self.specList.setGeometry(QtCore.QRect(10, 30, 311, 201))
        self.specList.setObjectName("specList")
        self.btUp = QtGui.QPushButton(self.frame)
        self.btUp.setGeometry(QtCore.QRect(330, 100, 25, 25))
        self.btUp.setText("")
        self.btUp.setObjectName("btUp")
        self.btDown = QtGui.QPushButton(self.frame)
        self.btDown.setGeometry(QtCore.QRect(330, 130, 25, 25))
        self.btDown.setText("")
        self.btDown.setObjectName("btDown")
        self.btDelete = QtGui.QPushButton(self.frame)
        self.btDelete.setGeometry(QtCore.QRect(400, 130, 25, 25))
        self.btDelete.setText("")
        self.btDelete.setObjectName("btDelete")
        self.btDuplicate = QtGui.QPushButton(self.frame)
        self.btDuplicate.setGeometry(QtCore.QRect(330, 170, 81, 27))
        self.btDuplicate.setObjectName("btDuplicate")
        self.txDupFactor = QtGui.QLineEdit(self.frame)
        self.txDupFactor.setGeometry(QtCore.QRect(330, 200, 113, 27))
        self.txDupFactor.setObjectName("txDupFactor")
        self.btClose = QtGui.QPushButton(self.centralwidget)
        self.btClose.setGeometry(QtCore.QRect(190, 300, 98, 27))
        self.btClose.setObjectName("btClose")
        FloatBox.setCentralWidget(self.centralwidget)
        self.statusbar = QtGui.QStatusBar(FloatBox)
        self.statusbar.setObjectName("statusbar")
        FloatBox.setStatusBar(self.statusbar)

        self.retranslateUi(FloatBox)
        QtCore.QMetaObject.connectSlotsByName(FloatBox)

    def retranslateUi(self, FloatBox):
        FloatBox.setWindowTitle(QtGui.QApplication.translate("FloatBox", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("FloatBox", "No. Trace Label", None, QtGui.QApplication.UnicodeUTF8))
        self.btPlot.setText(QtGui.QApplication.translate("FloatBox", "Plot Pattern...", None, QtGui.QApplication.UnicodeUTF8))
        self.btChange.setText(QtGui.QApplication.translate("FloatBox", "Change Label", None, QtGui.QApplication.UnicodeUTF8))
        self.btDuplicate.setText(QtGui.QApplication.translate("FloatBox", "Duplicate", None, QtGui.QApplication.UnicodeUTF8))
        self.txDupFactor.setText(QtGui.QApplication.translate("FloatBox", "1.0", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("FloatBox", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgSaveAsText.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgSaveAsText(object):
    def setupUi(self, DgSaveAsText):
        DgSaveAsText.setObjectName("DgSaveAsText")
        DgSaveAsText.resize(282, 201)
        self.frame = QtGui.QFrame(DgSaveAsText)
        self.frame.setGeometry(QtCore.QRect(10, 10, 261, 141))
        self.frame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.ckIgnoreMask = QtGui.QCheckBox(self.frame)
        self.ckIgnoreMask.setGeometry(QtCore.QRect(20, 10, 201, 22))
        self.ckIgnoreMask.setObjectName("ckIgnoreMask")
        self.label = QtGui.QLabel(self.frame)
        self.label.setGeometry(QtCore.QRect(40, 40, 181, 17))
        self.label.setObjectName("label")
        self.chMaskValue = QtGui.QComboBox(self.frame)
        self.chMaskValue.setGeometry(QtCore.QRect(110, 60, 131, 27))
        self.chMaskValue.setObjectName("chMaskValue")
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.txMaskValue = QtGui.QLineEdit(self.frame)
        self.txMaskValue.setGeometry(QtCore.QRect(110, 100, 131, 27))
        self.txMaskValue.setObjectName("txMaskValue")
        self.btSave = QtGui.QPushButton(DgSaveAsText)
        self.btSave.setGeometry(QtCore.QRect(20, 160, 121, 31))
        self.btSave.setObjectName("btSave")
        self.btCancel = QtGui.QPushButton(DgSaveAsText)
        self.btCancel.setGeometry(QtCore.QRect(190, 160, 81, 27))
        self.btCancel.setObjectName("btCancel")

        self.retranslateUi(DgSaveAsText)
        QtCore.QMetaObject.connectSlotsByName(DgSaveAsText)

    def retranslateUi(self, DgSaveAsText):
        DgSaveAsText.setWindowTitle(QtGui.QApplication.translate("DgSaveAsText", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.ckIgnoreMask.setText(QtGui.QApplication.translate("DgSaveAsText", "Ignore Masked Points", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgSaveAsText", "Replace Mask Value with", None, QtGui.QApplication.UnicodeUTF8))
        self.chMaskValue.setItemText(0, QtGui.QApplication.translate("DgSaveAsText", "Value below", None, QtGui.QApplication.UnicodeUTF8))
        self.chMaskValue.setItemText(1, QtGui.QApplication.translate("DgSaveAsText", "0", None, QtGui.QApplication.UnicodeUTF8))
        self.chMaskValue.setItemText(2, QtGui.QApplication.translate("DgSaveAsText", "-1", None, QtGui.QApplication.UnicodeUTF8))
        self.chMaskValue.setItemText(3, QtGui.QApplication.translate("DgSaveAsText", "Original Value", None, QtGui.QApplication.UnicodeUTF8))
        self.btSave.setText(QtGui.QApplication.translate("DgSaveAsText", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.btCancel.setText(QtGui.QApplication.translate("DgSaveAsText", "Cancel", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgFitting.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgFitting(object):
    def setupUi(self, DgFitting):
        DgFitting.setObjectName("DgFitting")
        DgFitting.resize(426, 569)
        self.frame = QtGui.QFrame(DgFitting)
        self.frame.setGeometry(QtCore.QRect(10, 10, 411, 71))
        self.frame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.cbTrace = QtGui.QComboBox(self.frame)
        self.cbTrace.setGeometry(QtCore.QRect(80, 10, 221, 27))
        self.cbTrace.setObjectName("cbTrace")
        self.label = QtGui.QLabel(self.frame)
        self.label.setGeometry(QtCore.QRect(0, 0, 66, 17))
        self.label.setObjectName("label")
        self.label_2 = QtGui.QLabel(self.frame)
        self.label_2.setGeometry(QtCore.QRect(120, 40, 41, 25))
        self.label_2.setObjectName("label_2")
        self.txRangeMin = QtGui.QLineEdit(self.frame)
        self.txRangeMin.setGeometry(QtCore.QRect(160, 40, 100, 25))
        self.txRangeMin.setObjectName("txRangeMin")
        self.txRangeMax = QtGui.QLineEdit(self.frame)
        self.txRangeMax.setGeometry(QtCore.QRect(300, 40, 100, 25))
        self.txRangeMax.setObjectName("txRangeMax")
        self.label_3 = QtGui.QLabel(self.frame)
        self.label_3.setGeometry(QtCore.QRect(280, 40, 21, 25))
        self.label_3.setObjectName("label_3")
        self.frame_2 = QtGui.QFrame(DgFitting)
        self.frame_2.setGeometry(QtCore.QRect(10, 90, 411, 101))
        self.frame_2.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.label_4 = QtGui.QLabel(self.frame_2)
        self.label_4.setGeometry(QtCore.QRect(0, 0, 71, 17))
        self.label_4.setObjectName("label_4")
        self.cbFunctions = QtGui.QComboBox(self.frame_2)
        self.cbFunctions.setGeometry(QtCore.QRect(10, 20, 261, 27))
        self.cbFunctions.setObjectName("cbFunctions")
        self.cbFunctions.addItem("")
        self.cbFunctions.addItem("")
        self.cbFunctions.addItem("")
        self.cbFunctions.addItem("")
        self.cbFunctions.addItem("")
        self.pnlFunction = QtGui.QLabel(self.frame_2)
        self.pnlFunction.setGeometry(QtCore.QRect(10, 50, 391, 50))
        self.pnlFunction.setText("")
        self.pnlFunction.setObjectName("pnlFunction")
        self.btLoadFunc = QtGui.QPushButton(self.frame_2)
        self.btLoadFunc.setGeometry(QtCore.QRect(280, 20, 121, 27))
        self.btLoadFunc.setObjectName("btLoadFunc")
        self.frame_3 = QtGui.QFrame(DgFitting)
        self.frame_3.setGeometry(QtCore.QRect(10, 200, 411, 321))
        self.frame_3.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_3.setObjectName("frame_3")
        self.label_5 = QtGui.QLabel(self.frame_3)
        self.label_5.setGeometry(QtCore.QRect(0, 0, 101, 17))
        self.label_5.setObjectName("label_5")
        self.txA1 = QtGui.QLineEdit(self.frame_3)
        self.txA1.setGeometry(QtCore.QRect(40, 50, 100, 25))
        self.txA1.setObjectName("txA1")
        self.label_6 = QtGui.QLabel(self.frame_3)
        self.label_6.setGeometry(QtCore.QRect(10, 50, 25, 25))
        self.label_6.setObjectName("label_6")
        self.ckA1 = QtGui.QCheckBox(self.frame_3)
        self.ckA1.setGeometry(QtCore.QRect(150, 50, 21, 25))
        self.ckA1.setText("")
        self.ckA1.setObjectName("ckA1")
        self.txA1r = QtGui.QLabel(self.frame_3)
        self.txA1r.setGeometry(QtCore.QRect(180, 50, 100, 25))
        self.txA1r.setObjectName("txA1r")
        self.label_8 = QtGui.QLabel(self.frame_3)
        self.label_8.setGeometry(QtCore.QRect(10, 80, 25, 25))
        self.label_8.setObjectName("label_8")
        self.txA2 = QtGui.QLineEdit(self.frame_3)
        self.txA2.setGeometry(QtCore.QRect(40, 80, 100, 25))
        self.txA2.setObjectName("txA2")
        self.ckA2 = QtGui.QCheckBox(self.frame_3)
        self.ckA2.setGeometry(QtCore.QRect(150, 80, 21, 25))
        self.ckA2.setText("")
        self.ckA2.setObjectName("ckA2")
        self.txA2r = QtGui.QLabel(self.frame_3)
        self.txA2r.setGeometry(QtCore.QRect(180, 80, 100, 25))
        self.txA2r.setObjectName("txA2r")
        self.txA3 = QtGui.QLineEdit(self.frame_3)
        self.txA3.setGeometry(QtCore.QRect(40, 110, 100, 25))
        self.txA3.setObjectName("txA3")
        self.txA4 = QtGui.QLineEdit(self.frame_3)
        self.txA4.setGeometry(QtCore.QRect(40, 140, 100, 25))
        self.txA4.setObjectName("txA4")
        self.txA5 = QtGui.QLineEdit(self.frame_3)
        self.txA5.setGeometry(QtCore.QRect(40, 170, 100, 25))
        self.txA5.setObjectName("txA5")
        self.txA6 = QtGui.QLineEdit(self.frame_3)
        self.txA6.setGeometry(QtCore.QRect(40, 200, 100, 25))
        self.txA6.setObjectName("txA6")
        self.txA7 = QtGui.QLineEdit(self.frame_3)
        self.txA7.setGeometry(QtCore.QRect(40, 230, 100, 25))
        self.txA7.setObjectName("txA7")
        self.txA8 = QtGui.QLineEdit(self.frame_3)
        self.txA8.setGeometry(QtCore.QRect(40, 260, 100, 25))
        self.txA8.setObjectName("txA8")
        self.label_10 = QtGui.QLabel(self.frame_3)
        self.label_10.setGeometry(QtCore.QRect(10, 110, 25, 25))
        self.label_10.setObjectName("label_10")
        self.label_11 = QtGui.QLabel(self.frame_3)
        self.label_11.setGeometry(QtCore.QRect(10, 140, 25, 25))
        self.label_11.setObjectName("label_11")
        self.label_12 = QtGui.QLabel(self.frame_3)
        self.label_12.setGeometry(QtCore.QRect(10, 170, 25, 25))
        self.label_12.setObjectName("label_12")
        self.label_13 = QtGui.QLabel(self.frame_3)
        self.label_13.setGeometry(QtCore.QRect(10, 200, 25, 25))
        self.label_13.setObjectName("label_13")
        self.label_14 = QtGui.QLabel(self.frame_3)
        self.label_14.setGeometry(QtCore.QRect(10, 230, 25, 25))
        self.label_14.setObjectName("label_14")
        self.label_15 = QtGui.QLabel(self.frame_3)
        self.label_15.setGeometry(QtCore.QRect(10, 260, 25, 25))
        self.label_15.setObjectName("label_15")
        self.ckA3 = QtGui.QCheckBox(self.frame_3)
        self.ckA3.setGeometry(QtCore.QRect(150, 110, 21, 25))
        self.ckA3.setText("")
        self.ckA3.setObjectName("ckA3")
        self.ckA4 = QtGui.QCheckBox(self.frame_3)
        self.ckA4.setGeometry(QtCore.QRect(150, 140, 21, 25))
        self.ckA4.setText("")
        self.ckA4.setObjectName("ckA4")
        self.ckA5 = QtGui.QCheckBox(self.frame_3)
        self.ckA5.setGeometry(QtCore.QRect(150, 170, 21, 25))
        self.ckA5.setText("")
        self.ckA5.setObjectName("ckA5")
        self.ckA6 = QtGui.QCheckBox(self.frame_3)
        self.ckA6.setGeometry(QtCore.QRect(150, 200, 21, 25))
        self.ckA6.setText("")
        self.ckA6.setObjectName("ckA6")
        self.ckA7 = QtGui.QCheckBox(self.frame_3)
        self.ckA7.setGeometry(QtCore.QRect(150, 230, 21, 25))
        self.ckA7.setText("")
        self.ckA7.setObjectName("ckA7")
        self.ckA8 = QtGui.QCheckBox(self.frame_3)
        self.ckA8.setGeometry(QtCore.QRect(150, 260, 21, 25))
        self.ckA8.setText("")
        self.ckA8.setObjectName("ckA8")
        self.txA3r = QtGui.QLabel(self.frame_3)
        self.txA3r.setGeometry(QtCore.QRect(180, 110, 100, 25))
        self.txA3r.setObjectName("txA3r")
        self.txA4r = QtGui.QLabel(self.frame_3)
        self.txA4r.setGeometry(QtCore.QRect(180, 140, 100, 25))
        self.txA4r.setObjectName("txA4r")
        self.txA5r = QtGui.QLabel(self.frame_3)
        self.txA5r.setGeometry(QtCore.QRect(180, 170, 100, 25))
        self.txA5r.setObjectName("txA5r")
        self.txA6r = QtGui.QLabel(self.frame_3)
        self.txA6r.setGeometry(QtCore.QRect(180, 200, 100, 25))
        self.txA6r.setObjectName("txA6r")
        self.txA7r = QtGui.QLabel(self.frame_3)
        self.txA7r.setGeometry(QtCore.QRect(180, 230, 100, 25))
        self.txA7r.setObjectName("txA7r")
        self.txA8r = QtGui.QLabel(self.frame_3)
        self.txA8r.setGeometry(QtCore.QRect(180, 260, 100, 25))
        self.txA8r.setObjectName("txA8r")
        self.label_22 = QtGui.QLabel(self.frame_3)
        self.label_22.setGeometry(QtCore.QRect(50, 20, 91, 21))
        self.label_22.setObjectName("label_22")
        self.label_23 = QtGui.QLabel(self.frame_3)
        self.label_23.setGeometry(QtCore.QRect(150, 20, 31, 21))
        self.label_23.setObjectName("label_23")
        self.label_24 = QtGui.QLabel(self.frame_3)
        self.label_24.setGeometry(QtCore.QRect(180, 20, 91, 21))
        self.label_24.setObjectName("label_24")
        self.txA1e = QtGui.QLabel(self.frame_3)
        self.txA1e.setGeometry(QtCore.QRect(290, 50, 120, 25))
        self.txA1e.setObjectName("txA1e")
        self.txA2e = QtGui.QLabel(self.frame_3)
        self.txA2e.setGeometry(QtCore.QRect(290, 80, 120, 25))
        self.txA2e.setObjectName("txA2e")
        self.txA3e = QtGui.QLabel(self.frame_3)
        self.txA3e.setGeometry(QtCore.QRect(290, 110, 120, 25))
        self.txA3e.setObjectName("txA3e")
        self.txA4e = QtGui.QLabel(self.frame_3)
        self.txA4e.setGeometry(QtCore.QRect(290, 140, 120, 25))
        self.txA4e.setObjectName("txA4e")
        self.txA5e = QtGui.QLabel(self.frame_3)
        self.txA5e.setGeometry(QtCore.QRect(290, 170, 120, 25))
        self.txA5e.setObjectName("txA5e")
        self.txA6e = QtGui.QLabel(self.frame_3)
        self.txA6e.setGeometry(QtCore.QRect(290, 200, 120, 25))
        self.txA6e.setObjectName("txA6e")
        self.txA7e = QtGui.QLabel(self.frame_3)
        self.txA7e.setGeometry(QtCore.QRect(290, 230, 120, 25))
        self.txA7e.setObjectName("txA7e")
        self.txA8e = QtGui.QLabel(self.frame_3)
        self.txA8e.setGeometry(QtCore.QRect(290, 260, 120, 25))
        self.txA8e.setObjectName("txA8e")
        self.txChisq = QtGui.QLabel(self.frame_3)
        self.txChisq.setGeometry(QtCore.QRect(240, 290, 120, 25))
        self.txChisq.setObjectName("txChisq")
        self.label_9 = QtGui.QLabel(self.frame_3)
        self.label_9.setGeometry(QtCore.QRect(180, 290, 68, 25))
        self.label_9.setObjectName("label_9")
        self.label_7 = QtGui.QLabel(self.frame_3)
        self.label_7.setGeometry(QtCore.QRect(290, 20, 68, 21))
        self.label_7.setObjectName("label_7")
        self.btCheck = QtGui.QPushButton(DgFitting)
        self.btCheck.setGeometry(QtCore.QRect(10, 530, 61, 27))
        self.btCheck.setObjectName("btCheck")
        self.btFitting = QtGui.QPushButton(DgFitting)
        self.btFitting.setGeometry(QtCore.QRect(100, 530, 121, 31))
        self.btFitting.setObjectName("btFitting")
        self.btClose = QtGui.QPushButton(DgFitting)
        self.btClose.setGeometry(QtCore.QRect(360, 540, 51, 27))
        self.btClose.setObjectName("btClose")

        self.retranslateUi(DgFitting)
        QtCore.QMetaObject.connectSlotsByName(DgFitting)
        DgFitting.setTabOrder(self.cbTrace, self.txRangeMin)
        DgFitting.setTabOrder(self.txRangeMin, self.txRangeMax)
        DgFitting.setTabOrder(self.txRangeMax, self.cbFunctions)
        DgFitting.setTabOrder(self.cbFunctions, self.btLoadFunc)
        DgFitting.setTabOrder(self.btLoadFunc, self.txA1)
        DgFitting.setTabOrder(self.txA1, self.ckA1)
        DgFitting.setTabOrder(self.ckA1, self.txA2)
        DgFitting.setTabOrder(self.txA2, self.ckA2)
        DgFitting.setTabOrder(self.ckA2, self.txA3)
        DgFitting.setTabOrder(self.txA3, self.ckA3)
        DgFitting.setTabOrder(self.ckA3, self.txA4)
        DgFitting.setTabOrder(self.txA4, self.ckA4)
        DgFitting.setTabOrder(self.ckA4, self.txA5)
        DgFitting.setTabOrder(self.txA5, self.ckA5)
        DgFitting.setTabOrder(self.ckA5, self.txA6)
        DgFitting.setTabOrder(self.txA6, self.ckA6)
        DgFitting.setTabOrder(self.ckA6, self.txA7)
        DgFitting.setTabOrder(self.txA7, self.ckA7)
        DgFitting.setTabOrder(self.ckA7, self.txA8)
        DgFitting.setTabOrder(self.txA8, self.ckA8)
        DgFitting.setTabOrder(self.ckA8, self.btCheck)
        DgFitting.setTabOrder(self.btCheck, self.btFitting)
        DgFitting.setTabOrder(self.btFitting, self.btClose)

    def retranslateUi(self, DgFitting):
        DgFitting.setWindowTitle(QtGui.QApplication.translate("DgFitting", "Fitting", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgFitting", "Data", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DgFitting", "From", None, QtGui.QApplication.UnicodeUTF8))
        self.txRangeMin.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txRangeMax.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DgFitting", "To", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DgFitting", "Function", None, QtGui.QApplication.UnicodeUTF8))
        self.cbFunctions.setItemText(0, QtGui.QApplication.translate("DgFitting", "Linear", None, QtGui.QApplication.UnicodeUTF8))
        self.cbFunctions.setItemText(1, QtGui.QApplication.translate("DgFitting", "Linear + Gauss", None, QtGui.QApplication.UnicodeUTF8))
        self.cbFunctions.setItemText(2, QtGui.QApplication.translate("DgFitting", "Linear + Lorentz", None, QtGui.QApplication.UnicodeUTF8))
        self.cbFunctions.setItemText(3, QtGui.QApplication.translate("DgFitting", "Linear + Gauss + Lorents", None, QtGui.QApplication.UnicodeUTF8))
        self.cbFunctions.setItemText(4, QtGui.QApplication.translate("DgFitting", "Linear + Gauss + Gauss", None, QtGui.QApplication.UnicodeUTF8))
        self.btLoadFunc.setText(QtGui.QApplication.translate("DgFitting", "Load Func File", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DgFitting", "Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.txA1.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("DgFitting", "A1", None, QtGui.QApplication.UnicodeUTF8))
        self.txA1r.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("DgFitting", "A2", None, QtGui.QApplication.UnicodeUTF8))
        self.txA2.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txA2r.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA3.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txA4.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txA5.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txA6.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txA7.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.txA8.setText(QtGui.QApplication.translate("DgFitting", "0.0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("DgFitting", "A3", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("DgFitting", "A4", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("DgFitting", "A5", None, QtGui.QApplication.UnicodeUTF8))
        self.label_13.setText(QtGui.QApplication.translate("DgFitting", "A6", None, QtGui.QApplication.UnicodeUTF8))
        self.label_14.setText(QtGui.QApplication.translate("DgFitting", "A7", None, QtGui.QApplication.UnicodeUTF8))
        self.label_15.setText(QtGui.QApplication.translate("DgFitting", "A8", None, QtGui.QApplication.UnicodeUTF8))
        self.txA3r.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA4r.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA5r.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA6r.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA7r.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA8r.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.label_22.setText(QtGui.QApplication.translate("DgFitting", "Initial Value", None, QtGui.QApplication.UnicodeUTF8))
        self.label_23.setText(QtGui.QApplication.translate("DgFitting", "Fix", None, QtGui.QApplication.UnicodeUTF8))
        self.label_24.setText(QtGui.QApplication.translate("DgFitting", "Result Value", None, QtGui.QApplication.UnicodeUTF8))
        self.txA1e.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA2e.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA3e.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA4e.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA5e.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA6e.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA7e.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txA8e.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txChisq.setText(QtGui.QApplication.translate("DgFitting", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("DgFitting", "ChiSq =", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("DgFitting", "Error", None, QtGui.QApplication.UnicodeUTF8))
        self.btCheck.setText(QtGui.QApplication.translate("DgFitting", "Check", None, QtGui.QApplication.UnicodeUTF8))
        self.btFitting.setText(QtGui.QApplication.translate("DgFitting", "Fitting", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DgFitting", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgGridSetting.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgGridSetting(object):
    def setupUi(self, DgGridSetting):
        DgGridSetting.setObjectName("DgGridSetting")
        DgGridSetting.resize(452, 252)
        self.frame = QtGui.QFrame(DgGridSetting)
        self.frame.setGeometry(QtCore.QRect(10, 10, 431, 91))
        self.frame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.label = QtGui.QLabel(self.frame)
        self.label.setGeometry(QtCore.QRect(10, 0, 131, 17))
        self.label.setObjectName("label")
        self.label_3 = QtGui.QLabel(self.frame)
        self.label_3.setGeometry(QtCore.QRect(20, 30, 90, 25))
        self.label_3.setObjectName("label_3")
        self.label_4 = QtGui.QLabel(self.frame)
        self.label_4.setGeometry(QtCore.QRect(20, 60, 90, 25))
        self.label_4.setObjectName("label_4")
        self.label_5 = QtGui.QLabel(self.frame)
        self.label_5.setGeometry(QtCore.QRect(220, 30, 51, 25))
        self.label_5.setObjectName("label_5")
        self.cbXlineColor = QtGui.QComboBox(self.frame)
        self.cbXlineColor.setGeometry(QtCore.QRect(270, 30, 141, 27))
        self.cbXlineColor.setObjectName("cbXlineColor")
        self.cbXlineColor.addItem("")
        self.cbXlineColor.addItem("")
        self.cbXlineColor.addItem("")
        self.cbXlineColor.addItem("")
        self.cbXlineColor.addItem("")
        self.cbXlineColor.addItem("")
        self.cbXlineColor.addItem("")
        self.spXlineWidth = QtGui.QSpinBox(self.frame)
        self.spXlineWidth.setGeometry(QtCore.QRect(110, 30, 60, 27))
        self.spXlineWidth.setObjectName("spXlineWidth")
        self.cbXlineStyle = QtGui.QComboBox(self.frame)
        self.cbXlineStyle.setGeometry(QtCore.QRect(110, 60, 141, 27))
        self.cbXlineStyle.setObjectName("cbXlineStyle")
        self.cbXlineStyle.addItem("")
        self.cbXlineStyle.addItem("")
        self.cbXlineStyle.addItem("")
        self.cbXlineStyle.addItem("")
        self.cbXlineStyle.addItem("")
        self.frame_2 = QtGui.QFrame(DgGridSetting)
        self.frame_2.setGeometry(QtCore.QRect(10, 110, 431, 91))
        self.frame_2.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.label_2 = QtGui.QLabel(self.frame_2)
        self.label_2.setGeometry(QtCore.QRect(10, 0, 91, 17))
        self.label_2.setObjectName("label_2")
        self.label_6 = QtGui.QLabel(self.frame_2)
        self.label_6.setGeometry(QtCore.QRect(20, 30, 90, 25))
        self.label_6.setObjectName("label_6")
        self.label_7 = QtGui.QLabel(self.frame_2)
        self.label_7.setGeometry(QtCore.QRect(20, 60, 90, 25))
        self.label_7.setObjectName("label_7")
        self.spYlineWidth = QtGui.QSpinBox(self.frame_2)
        self.spYlineWidth.setGeometry(QtCore.QRect(110, 30, 60, 27))
        self.spYlineWidth.setObjectName("spYlineWidth")
        self.label_8 = QtGui.QLabel(self.frame_2)
        self.label_8.setGeometry(QtCore.QRect(210, 30, 51, 25))
        self.label_8.setObjectName("label_8")
        self.cbYlineColor = QtGui.QComboBox(self.frame_2)
        self.cbYlineColor.setGeometry(QtCore.QRect(270, 30, 141, 27))
        self.cbYlineColor.setObjectName("cbYlineColor")
        self.cbYlineColor.addItem("")
        self.cbYlineColor.addItem("")
        self.cbYlineColor.addItem("")
        self.cbYlineColor.addItem("")
        self.cbYlineColor.addItem("")
        self.cbYlineColor.addItem("")
        self.cbYlineColor.addItem("")
        self.cbYlineStyle = QtGui.QComboBox(self.frame_2)
        self.cbYlineStyle.setGeometry(QtCore.QRect(110, 60, 141, 27))
        self.cbYlineStyle.setObjectName("cbYlineStyle")
        self.cbYlineStyle.addItem("")
        self.cbYlineStyle.addItem("")
        self.cbYlineStyle.addItem("")
        self.cbYlineStyle.addItem("")
        self.cbYlineStyle.addItem("")
        self.btClose = QtGui.QPushButton(DgGridSetting)
        self.btClose.setGeometry(QtCore.QRect(30, 210, 81, 27))
        self.btClose.setObjectName("btClose")

        self.retranslateUi(DgGridSetting)
        QtCore.QMetaObject.connectSlotsByName(DgGridSetting)

    def retranslateUi(self, DgGridSetting):
        DgGridSetting.setWindowTitle(QtGui.QApplication.translate("DgGridSetting", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgGridSetting", "X Grid Style", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DgGridSetting", "Line Width : ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DgGridSetting", "Line Style : ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DgGridSetting", "Color:", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineColor.setItemText(0, QtGui.QApplication.translate("DgGridSetting", "Blue", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineColor.setItemText(1, QtGui.QApplication.translate("DgGridSetting", "Green", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineColor.setItemText(2, QtGui.QApplication.translate("DgGridSetting", "Red", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineColor.setItemText(3, QtGui.QApplication.translate("DgGridSetting", "Cyan", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineColor.setItemText(4, QtGui.QApplication.translate("DgGridSetting", "Magenta", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineColor.setItemText(5, QtGui.QApplication.translate("DgGridSetting", "Yellow", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineColor.setItemText(6, QtGui.QApplication.translate("DgGridSetting", "Black", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineStyle.setItemText(0, QtGui.QApplication.translate("DgGridSetting", "Line", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineStyle.setItemText(1, QtGui.QApplication.translate("DgGridSetting", "Dotted", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineStyle.setItemText(2, QtGui.QApplication.translate("DgGridSetting", "Dashed", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineStyle.setItemText(3, QtGui.QApplication.translate("DgGridSetting", "Dot-dashed", None, QtGui.QApplication.UnicodeUTF8))
        self.cbXlineStyle.setItemText(4, QtGui.QApplication.translate("DgGridSetting", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DgGridSetting", "Y Grid Style", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("DgGridSetting", "Line Width : ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("DgGridSetting", "Line Style : ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("DgGridSetting", "Color:", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineColor.setItemText(0, QtGui.QApplication.translate("DgGridSetting", "Blue", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineColor.setItemText(1, QtGui.QApplication.translate("DgGridSetting", "Green", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineColor.setItemText(2, QtGui.QApplication.translate("DgGridSetting", "Red", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineColor.setItemText(3, QtGui.QApplication.translate("DgGridSetting", "Cyan", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineColor.setItemText(4, QtGui.QApplication.translate("DgGridSetting", "Magenta", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineColor.setItemText(5, QtGui.QApplication.translate("DgGridSetting", "Yellow", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineColor.setItemText(6, QtGui.QApplication.translate("DgGridSetting", "Black", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineStyle.setItemText(0, QtGui.QApplication.translate("DgGridSetting", "Line", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineStyle.setItemText(1, QtGui.QApplication.translate("DgGridSetting", "Dotted", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineStyle.setItemText(2, QtGui.QApplication.translate("DgGridSetting", "Dashed", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineStyle.setItemText(3, QtGui.QApplication.translate("DgGridSetting", "Dot-dashed", None, QtGui.QApplication.UnicodeUTF8))
        self.cbYlineStyle.setItemText(4, QtGui.QApplication.translate("DgGridSetting", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DgGridSetting", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgTickStyleSetting.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgTickStyleSetting(object):
    def setupUi(self, DgTickStyleSetting):
        DgTickStyleSetting.setObjectName("DgTickStyleSetting")
        DgTickStyleSetting.resize(320, 260)
        self.ckTopSideOn = QtGui.QCheckBox(DgTickStyleSetting)
        self.ckTopSideOn.setGeometry(QtCore.QRect(10, 10, 151, 22))
        self.ckTopSideOn.setObjectName("ckTopSideOn")
        self.ckRightSideOn = QtGui.QCheckBox(DgTickStyleSetting)
        self.ckRightSideOn.setGeometry(QtCore.QRect(160, 10, 141, 22))
        self.ckRightSideOn.setObjectName("ckRightSideOn")
        self.label = QtGui.QLabel(DgTickStyleSetting)
        self.label.setGeometry(QtCore.QRect(20, 50, 81, 17))
        self.label.setObjectName("label")
        self.line = QtGui.QFrame(DgTickStyleSetting)
        self.line.setGeometry(QtCore.QRect(10, 30, 301, 16))
        self.line.setFrameShape(QtGui.QFrame.HLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName("line")
        self.label_2 = QtGui.QLabel(DgTickStyleSetting)
        self.label_2.setGeometry(QtCore.QRect(130, 50, 68, 17))
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.txMajorLength = QtGui.QLineEdit(DgTickStyleSetting)
        self.txMajorLength.setGeometry(QtCore.QRect(200, 50, 100, 25))
        self.txMajorLength.setObjectName("txMajorLength")
        self.label_3 = QtGui.QLabel(DgTickStyleSetting)
        self.label_3.setGeometry(QtCore.QRect(130, 80, 68, 17))
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.txMajorWidth = QtGui.QLineEdit(DgTickStyleSetting)
        self.txMajorWidth.setGeometry(QtCore.QRect(200, 80, 100, 25))
        self.txMajorWidth.setObjectName("txMajorWidth")
        self.ckUseMinorTick = QtGui.QCheckBox(DgTickStyleSetting)
        self.ckUseMinorTick.setGeometry(QtCore.QRect(20, 110, 111, 22))
        self.ckUseMinorTick.setObjectName("ckUseMinorTick")
        self.label_4 = QtGui.QLabel(DgTickStyleSetting)
        self.label_4.setGeometry(QtCore.QRect(130, 110, 68, 17))
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.txMinorLength = QtGui.QLineEdit(DgTickStyleSetting)
        self.txMinorLength.setGeometry(QtCore.QRect(200, 110, 100, 25))
        self.txMinorLength.setObjectName("txMinorLength")
        self.label_5 = QtGui.QLabel(DgTickStyleSetting)
        self.label_5.setGeometry(QtCore.QRect(130, 140, 68, 17))
        self.label_5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_5.setObjectName("label_5")
        self.txMinorWidth = QtGui.QLineEdit(DgTickStyleSetting)
        self.txMinorWidth.setGeometry(QtCore.QRect(200, 140, 100, 25))
        self.txMinorWidth.setObjectName("txMinorWidth")
        self.btApply = QtGui.QPushButton(DgTickStyleSetting)
        self.btApply.setGeometry(QtCore.QRect(200, 170, 100, 30))
        self.btApply.setObjectName("btApply")
        self.line_2 = QtGui.QFrame(DgTickStyleSetting)
        self.line_2.setGeometry(QtCore.QRect(10, 200, 301, 16))
        self.line_2.setFrameShape(QtGui.QFrame.HLine)
        self.line_2.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.btRevert = QtGui.QPushButton(DgTickStyleSetting)
        self.btRevert.setGeometry(QtCore.QRect(40, 220, 60, 30))
        self.btRevert.setObjectName("btRevert")
        self.btClose = QtGui.QPushButton(DgTickStyleSetting)
        self.btClose.setGeometry(QtCore.QRect(220, 220, 60, 30))
        self.btClose.setObjectName("btClose")

        self.retranslateUi(DgTickStyleSetting)
        QtCore.QMetaObject.connectSlotsByName(DgTickStyleSetting)

    def retranslateUi(self, DgTickStyleSetting):
        DgTickStyleSetting.setWindowTitle(QtGui.QApplication.translate("DgTickStyleSetting", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.ckTopSideOn.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Top Side Ticks", None, QtGui.QApplication.UnicodeUTF8))
        self.ckRightSideOn.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Right Side Ticks", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Major Ticks", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Length :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Width :", None, QtGui.QApplication.UnicodeUTF8))
        self.ckUseMinorTick.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Minor Ticks", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Length :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Width :", None, QtGui.QApplication.UnicodeUTF8))
        self.btApply.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Apply", None, QtGui.QApplication.UnicodeUTF8))
        self.btRevert.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Revert", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DgTickStyleSetting", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'DgCalcDS.ui'
#
# Created: Tue May 28 12:03:16 2019
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgCalcDS(object):
    def setupUi(self, DgCalcDS):
        DgCalcDS.setObjectName("DgCalcDS")
        DgCalcDS.resize(256, 260)
        self.L1txt = QtGui.QLineEdit(DgCalcDS)
        self.L1txt.setGeometry(QtCore.QRect(50, 10, 81, 31))
        self.L1txt.setObjectName("L1txt")
        self.label = QtGui.QLabel(DgCalcDS)
        self.label.setGeometry(QtCore.QRect(10, 20, 31, 17))
        self.label.setObjectName("label")
        self.label_2 = QtGui.QLabel(DgCalcDS)
        self.label_2.setGeometry(QtCore.QRect(140, 20, 41, 17))
        self.label_2.setObjectName("label_2")
        self.btApply = QtGui.QPushButton(DgCalcDS)
        self.btApply.setGeometry(QtCore.QRect(190, 10, 51, 27))
        self.btApply.setObjectName("btApply")
        self.btClose = QtGui.QPushButton(DgCalcDS)
        self.btClose.setGeometry(QtCore.QRect(90, 230, 61, 27))
        self.btClose.setObjectName("btClose")
        self.line = QtGui.QFrame(DgCalcDS)
        self.line.setGeometry(QtCore.QRect(90, 40, 161, 16))
        self.line.setFrameShape(QtGui.QFrame.HLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName("line")
        self.line_2 = QtGui.QFrame(DgCalcDS)
        self.line_2.setGeometry(QtCore.QRect(0, 210, 251, 16))
        self.line_2.setFrameShape(QtGui.QFrame.HLine)
        self.line_2.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.label_3 = QtGui.QLabel(DgCalcDS)
        self.label_3.setGeometry(QtCore.QRect(0, 40, 91, 17))
        self.label_3.setObjectName("label_3")
        self.txtIndex = QtGui.QLabel(DgCalcDS)
        self.txtIndex.setGeometry(QtCore.QRect(10, 60, 91, 141))
        self.txtIndex.setObjectName("txtIndex")
        self.txtResults = QtGui.QLabel(DgCalcDS)
        self.txtResults.setGeometry(QtCore.QRect(100, 60, 151, 141))
        self.txtResults.setObjectName("txtResults")

        self.retranslateUi(DgCalcDS)
        QtCore.QMetaObject.connectSlotsByName(DgCalcDS)

    def retranslateUi(self, DgCalcDS):
        DgCalcDS.setWindowTitle(QtGui.QApplication.translate("DgCalcDS", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DgCalcDS", "L1 = ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DgCalcDS", "[mm]", None, QtGui.QApplication.UnicodeUTF8))
        self.btApply.setText(QtGui.QApplication.translate("DgCalcDS", "Apply", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DgCalcDS", "Close", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DgCalcDS", "Information", None, QtGui.QApplication.UnicodeUTF8))
        self.txtIndex.setText(QtGui.QApplication.translate("DgCalcDS", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))
        self.txtResults.setText(QtGui.QApplication.translate("DgCalcDS", "TextLabel", None, QtGui.QApplication.UnicodeUTF8))




from __future__ import print_function

# "cos", "sin", "tan", "acos", "asin", "atan","cosh", "sinh", "tanh", "exp","log", "log10","sqrt","ceil", "fabs","floor","pow"
# "atan2", "frexp","ldexp", "modf", "fmod", "hypot"

import math

class eisf:

    #---------------------------------------------------------------

    def __init__(self):
#        self.func = "p0+(p1+sin(p3*(p3/p2)+(p6+p1)+p3))+3.14"
#        self.func = "p0+p1+(p3+p4)"
#        self.func = "sin(p0)+tan(p1)"
#        self.func = "-p0/p1"
        self.q = 0
#        self.name =["p0","p1","p2","p3","p4","p5","p6"]
#        self.p    =["1" ,"2" ,"3" ,"4" ,"5" ,"6" ,"7" ]
#        self.p    =[
#                           ["1.0","1.1","1.2"],
#                           ["2.0","2.2","2.4"],
#                           ["3.0","3.3","3.6"],
#                           ["4.0","4.4","4.8"],
#                           ["5.0","5.5","6.0"],
#                           ["6.0","6.6","7.2"],
#                           ["7.0","7.7","8.4"]
#                          ]


    #---------------------------------------------------------------

    def divideListElem(self,divval,k):

        if k==0:
            self.ansdivval=float(self.substitute(divval[0]))
        else:
            self.ansdivval/=float(self.substitute(divval[k]))

    #---------------------------------------------------------------

    def multiplyListElem(self,multiplyval,j):

        if j==0:
            self.ansmultiplyval=float(self.substitute(multiplyval[0]))
        else:
            self.ansmultiplyval*=float(self.substitute(multiplyval[j]))

    #---------------------------------------------------------------

    def divideListElemErr(self,divval,divvale,k):
        if k==0:
            self.ansdivvalErr=float(self.substituteErr(divvale[0]))
        else:
            self.ansdivvalErr=math.sqrt((math.pow(float(self.substituteErr(divvale[k]))/float(self.substitute(divval[k])),2)\
                                    +math.pow((self.ansdivvalErr/self.ansdivval),2)))\
                                    *self.ansdivval/float(self.substitute(divval[k]))

    #---------------------------------------------------------------

    def multiplyListElemErr(self,multiplyval,multiplyvale,j):
    
        if j==0:
            self.ansmultiplyvalErr=float(self.substituteErr(multiplyvale[0]))
        else:
            self.ansmultiplyvalErr= math.sqrt((math.pow(float(self.substituteErr(multiplyvale[j]))/float(self.substitute(multiplyval[j])),2)\
                                    +math.pow((self.ansmultiplyvalErr/self.ansmultiplyval),2)))\
                                    *self.ansmultiplyval*float(self.substitute(multiplyval[j]))
    #---------------------------------------------------------------

    def substractListElem(self,subval,i):

        if i==0:
            self.anssubval=float(self.substitute(subval[0]))
        else:
            self.anssubval-=float(self.substitute(subval[i]))

    #---------------------------------------------------------------

    def addListElem(self,addval,l):

        if l==0:
            self.ansaddval=float(self.substitute(addval[0]))
        else:
            self.ansaddval+=float(self.substitute(addval[l]))

    #---------------------------------------------------------------

    def substractListElemErr(self,subvale,i):
        print(i,subvale)
        if i==0:
            self.anssubvalErr=float(self.substituteErr(subvale[0]))
        else:
            self.anssubvalErr= math.sqrt(math.pow(self.anssubvalErr,2)+ math.pow(float(self.substituteErr(subvale[i])),2))

    #---------------------------------------------------------------

    def addListElemErr(self,addvale,l):

        if l==0:
            self.ansaddvalErr = float(self.substituteErr(addvale[0]))
        else:
            self.ansaddvalErr = math.sqrt(math.pow(self.ansaddvalErr,2)+ math.pow(float(self.substituteErr(addvale[l])),2))


    #---------------------------------------------------------------

    def substitute(self,val):
        #print "---a",val
        if "p" in val:
            index=val.split("p")[1]
            #print "p"
            return self.p[int(index)-1][self.q]
        elif "x" in val or "Q" in val:
            #print "---",self.p[-1][self.q]
            return self.p[-1][self.q]
        else:
            #print "else"
            return val

    #---------------------------------------------------------------

    def substituteErr(self,val):
        #print "---a",val
        if "p" in val:
            index=val.split("p")[1]
            #print "p"
            return self.e[int(index)-1][self.q]
        elif "x" in val or "Q" in val:
            #print "---",self.p[-1][self.q]
            return self.e[-1][self.q]
        else:
            #print "else"
            return val

    #---------------------------------------------------------------

    def arithmeticOperation(self,inputParam):
        print("D-",inputParam)
        if not inputParam.replace(".","").replace("p","").replace("x","1").replace("Q","1").replace("|","").isdigit():
            if "|" in inputParam:
                addval=(inputParam.split("|"))[0].split("+")
                addvalErr=(inputParam.split("|"))[1].split("+")
            else:
                addval=inputParam.split("+")
                addvalErr=inputParam.split("+")

            for l in range(len(addval)): #==> + start addition term
                if not addval[l].replace(".","").replace("p","").replace("x","1").replace("Q","1").replace("e+","").replace("e-","").isdigit():
                    subval=addval[l].replace("e+","EP").replace("e-","EM").split("-")
                    subvalErr=addvalErr[l].replace("e+","EP").replace("e-","EM").split("-")

                    if subval[0]=="" and subvalErr[0]!="":
                        subval[0]="0"
                        subvalErr.insert(0,"0")
                    if subvalErr[0]=="" and subval[0]!="":
                        subval.insert(0,"0")
                        subvalErr[0]="0"
                    if subvalErr[0]=="" and subval[0]=="":
                        subval[0]="0"
                        subvalErr[0]="0"

                    subval=[subvalsp.replace("EP","e+").replace("EM","e-") for subvalsp in subval]
                    subvalErr=[subvalErrsp.replace("EP","e+").replace("EM","e-") for subvalErrsp in subvalErr]

                    #print "$$$$$",subval
                    for i in range(len(subval)): #==> - start substraction term
                        if not self.rep(subval[i]).isdigit():
                            multiplyval=subval[i].split("*")
                            multiplyvalErr=subvalErr[i].split("*")
                            for j in range(len(multiplyval)): #==> * start nultiplication term
                                if not self.rep(multiplyval[j]).isdigit():
                                    divval=multiplyval[j].split("/")
                                    divvalErr=multiplyvalErr[j].split("/")

                                    for k in range(len(divval)): #==> / start division term
                                        if not self.rep(divval[k]).replace("-","").isdigit():
                                            self.ansdivval=0
                                            self.ansdivvalErr=0

                                        if self.rep(divval[k]).isdigit():
                                            self.divideListElemErr(divval,divvalErr,k)
                                            self.divideListElem(divval,k)

                                            #print "$$$$",divval
                                    #multiplyval[j]=str(self.ansdivval)  #==> / end
                                    st=self.ansdivval
                                    multiplyval[j]= '%(st).16f' % vars()
                                    ste=self.ansdivvalErr
                                    multiplyvalErr[j]= '%(ste).16f' % vars()
                                if self.rep(multiplyval[j]).isdigit():
                                    self.multiplyListElemErr(multiplyval,multiplyvalErr,j)
                                    self.multiplyListElem(multiplyval,j)
                                    #print "$$$",multiplyval
                            #subval[i] = str(self.ansmultiplyval) #==> * end
                            st = self.ansmultiplyval
                            subval[i] = '%(st).16f' % vars()
                            ste = self.ansmultiplyvalErr
                            subvalErr[i] = '%(ste).16f' % vars()
                        if self.rep(subval[i]).isdigit():
                            self.substractListElem(subval,i)
                            self.substractListElemErr(subvalErr,i)
                            #print "$$",subval
                    #addval[l] = str(self.anssubval) #==> - end
                    st=self.anssubval
                    addval[l] = '%(st).16f' % vars()
                    ste=self.anssubvalErr
                    addvalErr[l] = '%(ste).16f' % vars()

                if self.rep(addval[l]).isdigit():
                    self.addListElem(addval,l)
                    self.addListElemErr(addvalErr,l)

                    #print "$",addval
            #ansval = str(self.ansaddval) #==> + end
            #print "###",ansval
            st=self.ansaddval
            ansval = '%(st).16f' % vars() #==> + end
            ste=self.ansaddvalErr
            ansvalErr = '%(ste).16f' % vars() #==> + end

            #print "###",ansval,st,inputParam
        else:
            if "|" in inputParam:
                ansval=self.substitute(inputParam.split("|")[0])
                ansvalErr=self.substituteErr(inputParam.split("|")[1])
            else:
                ansval=self.substitute(inputParam)
                ansvalErr=self.substituteErr(inputParam)

            #print "###",ansval,"---",inputParam
        print("A-",ansval,ansvalErr)
        return ansval,ansvalErr

    def rep(self,text):

        text = text.replace(".","")
        text = text.replace("p","")
        text = text.replace("x","1")
        text = text.replace("Q","1")
        text = text.replace("e+","")
        text = text.replace("e-","")
        text = text.replace("-","")

        return text

    #---------------------------------------------------------------

    def connection(self,paramlist):
        result=""
        for i in range(len(paramlist)):
            result+=str(paramlist[i])

        return result

    #---------------------------------------------------------------

    def checkFuncNamePos(self,func,param):
        return param.find(func)==len(param)-len(func) and param.find(func)>=0

    #---------------------------------------------------------------

    def associativeAction(self,paramlist):
        #print "---c",paramlist
        subcoefficient=0
        if len(paramlist)!=3:
            return self.connection(paramlist) 
        else:
            if paramlist[1][1:-1].find(",")==-1:
                afterPartialCalc,afterPartialCalcErr=self.arithmeticOperation(paramlist[1][1:-1])
            else:
                afterPartialCalc,afterPartialCalcErr=self.arithmeticOperation(paramlist[1][1:-1].split(",")[0])
                subcoefficient=float(paramlist[1][1:-1].split(",")[1])
            # sinh
            if self.checkFuncNamePos("sinh",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("sinh")]
                val2=str(math.sinh(float(afterPartialCalc)))
                val3=str(math.sinh(float(afterPartialCalcErr)))
            # cosh
            elif self.checkFuncNamePos("cosh",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("cosh")]
                val2=str(math.cosh(float(afterPartialCalc)))
                val3=str(math.cosh(float(afterPartialCalcErr)))
            # tanh
            elif self.checkFuncNamePos("tanh",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("tanh")]
                val2=str(math.tanh(float(afterPartialCalc)))
                val3=str(math.tanh(float(afterPartialCalcErr)))
            # sin
            elif self.checkFuncNamePos("sin",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("sin")]
                val2=str(math.sin(float(afterPartialCalc)))
                val3=str(math.sin(float(afterPartialCalcErr)))
            # cos
            elif self.checkFuncNamePos("cos",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("cos")]
                val2=str(math.cos(float(afterPartialCalc)))
                val3=str(math.cos(float(afterPartialCalcErr)))
            # tan
            elif self.checkFuncNamePos("tan",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("tan")]
                val2=str(math.tan(float(afterPartialCalc)))
                val3=str(math.tan(float(afterPartialCalcErr)))
            # asin
            elif self.checkFuncNamePos("asin",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("asin")]
                if float(afterPartialCalc)>1:
                    print("x in asin(x) needs to be lower than 1.")
                    val2="0"
                    val3="0"
                else:
                    val2=str(math.asin(float(afterPartialCalc)))
                    val3=str(math.asin(float(afterPartialCalcErr)))
            # acos
            elif self.checkFuncNamePos("acos",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("acos")]
                if float(afterPartialCalc)>1:
                    print("x in acos(x) needs to be lower than 1.")
                    val2="0"
                    val3="0"
                else:
                    val2=str(math.acos(float(afterPartialCalc)))
                    val3=str(math.acos(float(afterPartialCalcErr)))
            # atan
            elif self.checkFuncNamePos("atan",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("atan")]
                val2=str(math.atan(float(afterPartialCalc)))
                val3=str(math.atan(float(afterPartialCalcErr)))
            # exp
            elif self.checkFuncNamePos("exp",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("exp")]
                val2=str(math.exp(float(afterPartialCalc)))
                val3=str(math.exp(float(afterPartialCalcErr)))
            # log10
            elif self.checkFuncNamePos("log10",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("log10")]
                if float(afterPartialCalc)<-1:
                    print("x in log10(x) needs to be larger than -1.")
                    val2="0"
                    val3="0"
                else:
                    val2=str(math.log10(float(afterPartialCalc)))
                    val3=str(math.log10(float(afterPartialCalcErr)))
            # log
            elif self.checkFuncNamePos("log",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("log")]
                if float(afterPartialCalc)<-1:
                    print("x in log(x) needs to be larger than -1.")
                    val2="0"
                    val3="0"
                else:
                    val2=str(math.log(float(afterPartialCalc)))
                    val3=str(math.log(float(afterPartialCalcErr)))
            # sqrt
            elif self.checkFuncNamePos("sqrt",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("sqrt")]
                if float(afterPartialCalc)<0:
                    print("x in sqrt(x) needs to be larger than -1.")
                    val2="0"
                    val3="0"
                else:
                    val2=str(math.sqrt(float(afterPartialCalc)))
                    val3=str(math.sqrt(float(afterPartialCalcErr)))
            # ceil
            elif self.checkFuncNamePos("ceil",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("ceil")]
                val2=str(math.ceil(float(afterPartialCalc)))
                val3=str(math.ceil(float(afterPartialCalcErr)))
            # fabs
            elif self.checkFuncNamePos("fabs",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("fabs")]
                val2=str(math.fabs(float(afterPartialCalc)))
                val3=str(math.fabs(float(afterPartialCalcErr)))
            # floor
            elif self.checkFuncNamePos("floor",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("floor")]
                val2=str(math.floor(float(afterPartialCalc)))
                val3=str(math.floor(float(afterPartialCalcErr)))
            # pow
            elif self.checkFuncNamePos("pow",paramlist[0]):
                val1=paramlist[0][:paramlist[0].find("pow")]
                val2=str(math.pow(float(afterPartialCalc),subcoefficient))
                val3=str(math.pow(float(afterPartialCalcErr),subcoefficient))
            else:
                val1=paramlist[0]
                val2=afterPartialCalc
                val3=afterPartialCalcErr
            return self.connection([val1,val2,paramlist[2]])+"|"+self.connection([val1,val3,paramlist[2]])

    #---------------------------------------------------------------

    def main_loop(self,param):

        r = param.find(")")
        l = param.rfind("(",0,r)+1

        if r==-1 and l==0:
            sp = ["","("+param+")",""]
        else:
            sp = [param[0:l-1], param[l-1:r+1], param[r+1:]]
        return self.associativeAction(sp)

    #---------------------------------------------------------------

    def main(self,initialFunc,param):
        #print param
        self.func=initialFunc
        self.p=param
        result =[]
        for i in range(len(self.p[0])):
            while -1:
                self.func = self.main_loop(self.func)
                   
                if self.func.find(")")==-1 and (self.func.find("-")<=0):
                    afterPartialCalc=self.arithmeticOperation(self.func)
                    break
            result.append(float(afterPartialCalc))
            self.func=initialFunc
            #print afterPartialCalc,"-- end"
            self.q+=1

        return result
    #---------------------------------------------------------------

    def mainWithError(self,initialFunc,param,paramErr):
        #print param
        self.func=initialFunc
        self.funce=initialFunc
        self.p=param
        self.e=paramErr
        result =[]
        resultErr =[]
        for i in range(len(self.p[0])):
            while -1:
                self.func = self.main_loop(self.func)
                   
                if self.func.find(")")==-1 and (self.func.find("-")<=0):
                    afterPartialCalc,afterPartialCalcErr=self.arithmeticOperation(self.func)
                    print("B-",afterPartialCalc,afterPartialCalcErr)
                    break
            result.append(float(afterPartialCalc))
            resultErr.append(float(afterPartialCalcErr))
            self.func=initialFunc
            #print afterPartialCalc,"-- end"
            self.q+=1

        return result,resultErr
    #---------------------------------------------------------------


if __name__ == "__main__":
    func = "p1*p1+p2"
    #func = "pow(p1,2)+p2"
    print("Function >> ",func)

    param    = [
                        ["1.0","1.1","1.2"],
                        ["2.0","2.2","2.4"],
                        ["3.0","3.3","3.6"],
                        ["4.0","4.4","4.8"],
                        ["5.0","5.5","6.0"],
                        ["6.0","6.6","7.2"],
                        ["7.0","7.7","8.4"]
                        ]

    app = eisf()
    #app.arithmeticOperation()
    result=app.main(func,param)

    print(result, "<-- result")
